Routes is a Python re-implementation of the Rails routes system for mapping
URL's to Controllers/Actions and generating URL's. Routes makes it easy to
create pretty and concise URL's that are RESTful with little effort.

Speedy and dynamic URL generation means you get a URL with minimal cruft
(no big dangling query args). Shortcut features like Named Routes cut down
on repetitive typing.

See `the documentation for installation and usage of Routes <http://readthedocs.org/docs/routes/en/latest/>`_.

.. image:: https://secure.travis-ci.org/bbangert/routes.png?branch=master
   :alt: Build Status
   :target: https://secure.travis-ci.org/bbangert/routes
